==> raml-client-2.0.7.tgz: package/src/authentication/authWindow.js <==
/**
 * Keep track of open popup windows so we only have one open at a time.
 *
 * @type {Object}
 */
let openPopup;
let openModal;
let closeInterval;

/**
 * Closes previously opened windows and modals.
 */
function closeAll() {
  if (openPopup) { openPopup.close(); }
  if (openModal) { openModal.close(); }

  openPopup = null;
  openModal = null;

  window.clearInterval(closeInterval);
}

/**
 * Pop open an authentication window. It adds some additional safe guards such
 * as catching blocked popup windows, listening for window closes, simplified
 * window positioning, etc.
 *
 * @return {Object} Execute `close` when the window is safe to cleared.
 */
module.exports = function (url, cb) {
  const width = Math.min(720, window.screen.availWidth);
  const height = Math.min(480, window.screen.availHeight);
  const top = Math.min(100, (window.screen.availHeight - height) / 2);
  const left = (window.screen.availWidth - width) / 2;

  function done(err) {
    closeAll();

    cb(err);
  }

  // Close previously open popup windows and modals.
  closeAll();

  // Open a popup window when the authentication button is pressed.
  openPopup = window.open(url, '', [
    `top=${top}`,
    `left=${left}`,
    `width=${width}`,
    `height=${height}`,
    'scrollbars=1'
  ].join(','));

  if (typeof openPopup !== 'object') {
    openPopup = null;
    done(new Error('Popup window blocked.'));
  }

  // Catch window closes before authentication is complete.
  closeInterval = window.setInterval(() => {
    if (openPopup.closed) {
      openPopup = null;
      done(new Error('Popup window closed.'));
    }
  }, 400);

  return {
    close() {
      // Remove any references to open modals and windows.
      return closeAll();
    }
  };
};

==> raml-client-2.1.0.tgz: package/src/authentication/authWindow.js <==
/**
 * Keep track of open popup windows so we only have one open at a time.
 *
 * @type {Object}
 */
let openPopup;
let openModal;
let closeInterval;

/**
 * Closes previously opened windows and modals.
 */
function closeAll() {
  if (openPopup) { openPopup.close(); }
  if (openModal) { openModal.close(); }

  openPopup = null;
  openModal = null;

  window.clearInterval(closeInterval);
}

/**
 * Pop open an authentication window. It adds some additional safe guards such
 * as catching blocked popup windows, listening for window closes, simplified
 * window positioning, etc.
 *
 * @return {Object} Execute `close` when the window is safe to cleared.
 */
module.exports = function (url, cb) {
  const width = Math.min(720, window.screen.availWidth);
  const height = Math.min(480, window.screen.availHeight);
  const top = Math.min(100, (window.screen.availHeight - height) / 2);
  const left = (window.screen.availWidth - width) / 2;

  function done(err) {
    closeAll();

    cb(err);
  }

  // Close previously open popup windows and modals.
  closeAll();

  // Open a popup window when the authentication button is pressed.
  openPopup = window.open(url, '', [
    `top=${top}`,
    `left=${left}`,
    `width=${width}`,
    `height=${height}`,
    'scrollbars=1'
  ].join(','));

  if (typeof openPopup !== 'object') {
    openPopup = null;
    done(new Error('Popup window blocked'));
  }

  // Catch window closes before authentication is complete.
  closeInterval = window.setInterval(() => {
    if (openPopup.closed) {
      openPopup = null;
      done(new Error('Popup window closed'));
    }
  }, 400);

  return {
    close() {
      // Remove any references to open modals and windows.
      return closeAll();
    }
  };
};
